Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(875)

Unified Diff: tools/dom/docs/lib/docs.dart

Issue 19931008: Fix paths in DOM doc test. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/dom/docs/bin/docs.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/dom/docs/lib/docs.dart
diff --git a/tools/dom/docs/lib/docs.dart b/tools/dom/docs/lib/docs.dart
index a05bd29538fba31a6d8b6c8da1ed49bc39436c9c..190a679fa190f25391a123512fad9f4704654e57 100644
--- a/tools/dom/docs/lib/docs.dart
+++ b/tools/dom/docs/lib/docs.dart
@@ -27,7 +27,7 @@ const List<String> HTML_LIBRARY_NAMES = const ['dart:html',
'dart:web_sql'];
/**
* Converts the libraries in [HTML_LIBRARY_NAMES] to a json file at [jsonPath]
* given the library path at [libPath].
*
* The json output looks like:
* {
@@ -51,13 +51,13 @@ const List<String> HTML_LIBRARY_NAMES = const ['dart:html',
*
* Completes to `true` if any errors were encountered, `false` otherwise.
*/
-Future<bool> convert(String libPath, String jsonPath) {
+Future<bool> convert(String libUri, String jsonPath) {
var paths = <String>[];
for (var libraryName in HTML_LIBRARY_NAMES) {
paths.add(libraryName);
}
- return analyze(paths, libPath, options: ['--preserve-comments'])
+ return analyze(paths, libUri, options: ['--preserve-comments'])
.then((MirrorSystem mirrors) {
var convertedJson = _generateJsonFromLibraries(mirrors);
return _exportJsonToFile(convertedJson, jsonPath);
@@ -27,7 +27,7 @@ const List<String> HTML_LIBRARY_NAMES = const ['dart:html',
/**
* Converts the libraries in [HTML_LIBRARY_NAMES] to a json file at [jsonPath]
- * given the library path at [libPath].
+ * given the library path at [libUri].
*
* The json output looks like:
« no previous file with comments | « tools/dom/docs/bin/docs.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698